Welcome to the Lewis documentation!
===================================
Lewis is a Python package that makes it easy to develop complex stateful device simulations. It
is licensed under GPL version 3 and the source is available on github_, where you are welcome to
open new issues so the package can improve.

Documentation contents:

Quickstart
==========
.. toctree::
   :maxdepth: 2
   :glob:
   :caption: Quickstart

   quickstart


.. toctree::
   :maxdepth: 2
   :glob:
   :caption: User guide

   user_guide/*


.. toctree::
   :maxdepth: 1
   :glob:
   :caption: Developer guide

   developer_guide/*

.. toctree::
   :maxdepth: 1
   :caption: Release notes
   :glob:

   release_notes/release_notes*

.. toctree::
   :titlesonly:
   :caption: API reference

   _api


.. _github: https://github.com/ISISComputingGroup/lewis
